@@ -263,6 +263,7 @@ class api:
     amo (str, optional) : "YES" or "NO", whether to place the order as AMO .Defaults to "NO".
     splitorder (str, optional): The split order  (e.g. "NO,YES"). Defaults to "NO".
     split_quantity (int, optional): The quantity to be split in the order. Defaults to 1. Set the value max to "Freeze quantity" to slice larger orders
+    strategy (str, optional) : Name of the trading strategy to use, default is "Python".
     api_key (str, optional): The API key to use. Defaults to "default".
     api_secret (str, optional): The API secret to use. Defaults to "default".
     
@@ -573,6 +574,7 @@ class api:
         price(float, optional): The price for the trade, Defaults to 0.
         splitorder (str, optional): The split order  (e.g. "NO,YES"). Defaults to "NO".
         split_quantity (int, optional): The quantity to be split in the order. Defaults to 1. Set the value max to "Freeze quantity" to slice larger orders
+        strategy (str, optional) : Name of the trading strategy to use, default is "Python".
         api_key (str, optional): The API key to use. Defaults to "default".
         api_secret (str, optional): The API secret to use. Defaults to "default".
 
@@ -676,7 +678,7 @@ class api:
         return (r.json())
 
     
-    def ModifyOrder(self,broker: str,exchange: str,symbol: str,order_id: str,action: str,product: str,pricetype: str ,quantity: int,price: float=0,disclosed_quantity: int=0,trigger_price: float=0,api_key: str="default", api_secret: str="default"):
+    def ModifyOrder(self,broker: str,exchange: str,symbol: str,order_id: str,action: str,product: str,pricetype: str ,quantity: int,price: float=0,disclosed_quantity: int=0,trigger_price: float=0,   strategy: str = "Python", api_key: str="default", api_secret: str="default"):
         """This function modifies an open order for the specified symbol on a specified exchange through the specified broker.
 
     Parameters
@@ -694,6 +696,7 @@ class api:
         trigger_price (float, optional): The trigger price for the order. Defaults to 0.
         splitorder (str, optional): The split order  (e.g. "NO,YES"). Defaults to "NO".
         split_quantity (int, optional): The quantity to be split in the order. Defaults to 1. Set the value max to "Freeze quantity" to slice larger orders
+        strategy (str, optional) : Name of the trading strategy to use, default is "Python".
         api_key (str, optional): The API key to use. Defaults to "default".
         api_secret (str, optional): The API secret to use. Defaults to "default".
 
@@ -709,6 +712,7 @@ class api:
             "api_secret":api_secret,
             "data":{    
                       "broker":broker,
+                      "strategy":strategy,
                       "exchange":exchange,
                       "symbol":symbol,
                       "order_id":order_id,
@@ -726,7 +730,7 @@ class api:
         r = requests.post(url, data=json.dumps(data), headers=self.headers)
         return (r.json())
     
-    def CancelOrder(self, broker: str,order_id: str, api_key: str="default", api_secret: str="default"):
+    def CancelOrder(self, broker: str,order_id: str, strategy: str = "Python", api_key: str="default", api_secret: str="default"):
 
         """This function Cancel the specified open order on the specified broker based on the order id.
 
@@ -734,6 +738,7 @@ class api:
     ----------
         broker (str): the broker to cancel the order on
         order_id (str/int): the id of the order to cancel
+        strategy (str, optional) : Name of the trading strategy to use, default is "Python".
         api_key (str, optional): The API key to use. Defaults to "default".
         api_secret (str, optional): The API secret to use. Defaults to "default".
 
@@ -750,6 +755,7 @@ class api:
             "data":
                 {
                     "broker": broker,
+                    "strategy":strategy,
                     "order_id":str(order_id)
                 }
 
@@ -758,12 +764,13 @@ class api:
         r = requests.post(url, data=json.dumps(data), headers=self.headers)
         return (r.json())
     
-    def CancelAllOrder(self, broker: str,api_key: str="default", api_secret: str="default"):
+    def CancelAllOrder(self, broker: str, strategy: str = "Python",  api_key: str="default", api_secret: str="default"):
         """This function Cancel's all the open order on the specified broker .
 
     Parameters
     ----------
         broker (str): the broker to cancel the order on
+        strategy (str, optional) : Name of the trading strategy to use, default is "Python".
         api_key (str, optional): The API key to use. Defaults to "default".
         api_secret (str, optional): The API secret to use. Defaults to "default".
 
@@ -778,7 +785,8 @@ class api:
             "api_secret": api_secret,
             "data":
                 {
-                    "broker": broker
+                    "broker": broker,
+                    "strategy":strategy
                 }
 
         }
@@ -977,7 +985,52 @@ class api:
         r = requests.post(url, data=json.dumps(data), headers=self.headers)
         return (r.json())
     
-    def SquareOffPosition(self,broker: str,exchange: str,product: str,symbol: str,api_key: str="default", api_secret: str="default"):
+
+    def AllPositions(self,broker: str,symbol: str="",product: str="",api_key: str="default", api_secret: str="default"):
+        """This function display's the open positions of the specified broker .
+
+    Parameters
+    ----------
+        broker (str): The name of the broker short code. (e.g ab - aliceblue,an - angelone, fs - firstock, up- upstox, ze- zerodha ). Refer API Docs appendix for complete broker code.
+        symbol(str, optional): The symbol for the order.
+        product (str, optional): The product type for the order (e.g. "CNC,MIS,NRML").
+        api_key (str, optional): The API key to use. Defaults to "default".
+        api_secret (str, optional): The API secret to use. Defaults to "default".
+
+    Returns:
+        dict: A dictionary containing the openpositions response from the Broker.
+    """
+
+        if (api_key == "default" and api_secret == "default"):
+            api_key = self.api_key
+            api_secret = self.api_secret
+        if(symbol==""):
+            data = {
+                "api_key": api_key,
+                "api_secret": api_secret,
+                "data":
+                    {
+                        "broker": broker
+                    }
+
+            }
+        else:
+            data = {
+                "api_key": api_key,
+                "api_secret": api_secret,
+                "data":
+                    {
+                        "broker": broker,
+                        "symbol":symbol,
+                        "product":product
+                    }
+
+            }
+        url = self.burl + "AllPositions"
+        r = requests.post(url, data=json.dumps(data), headers=self.headers)
+        return (r.json())
+    
+    def SquareOffPosition(self,broker: str,exchange: str,product: str,symbol: str, strategy: str = "Python", api_key: str="default", api_secret: str="default"):
         """This function squares off the position for the specified symbol on a specified exchange through the specified broker.
 
     Parameters
@@ -986,6 +1039,7 @@ class api:
         exchange (str): The name of the exchange (NSE,NFO,BSE,BFO,MCX,CDS).
         product (str): The product type for the order (e.g. "CNC,MIS,NRML").
         symbol (str): The symbol for the order.
+        strategy (str, optional) : Name of the trading strategy to use, default is "Python".
         api_key (str, optional): The API key to use. Defaults to "default".
         api_secret (str, optional): The API secret to use. Defaults to "default".
 
@@ -1001,6 +1055,7 @@ class api:
             "data":
                 {
                     "broker": broker,
+                    "strategy":strategy,
                     "exchange":exchange,
                     "product":product,
                     "symbol":symbol
@@ -1011,12 +1066,13 @@ class api:
         r = requests.post(url, data=json.dumps(data), headers=self.headers)
         return (r.json())
     
-    def SquareOffAllPosition(self,broker: str,api_key: str="default", api_secret: str="default"):
+    def SquareOffAllPosition(self,broker: str,strategy: str = "Python", api_key: str="default", api_secret: str="default"):
         """This function squares of all the postion of the specified broker .
 
     Parameters
     ----------
     broker (str): The name of the broker short code. (e.g ab - aliceblue,an - angelone, fs - firstock, up- upstox, ze- zerodha ). Refer API Docs appendix for complete broker code.
+    strategy (str, optional) : Name of the trading strategy to use, default is "Python".
     api_key (str, optional): The API key to use. Defaults to "default".
     api_secret (str, optional): The API secret to use. Defaults to "default".
 
@@ -1031,7 +1087,8 @@ class api:
             "api_secret": api_secret,
             "data":
                 {
-                    "broker": broker
+                    "broker": broker,
+                    "strategy":strategy
                 }
 
         }
@@ -1096,13 +1153,14 @@ class api:
         r = requests.post(url, data=json.dumps(data), headers=self.headers)
         return (r.json())
     
-    def ExitBOOrder(self, broker: str,order_id: str, api_key: str="default", api_secret: str="default"):
+    def ExitBOOrder(self, broker: str,order_id: str, strategy: str = "Python", api_key: str="default", api_secret: str="default"):
         """This function exits the specified open bracket order on the specified broker based on the order id.
 
     Parameters
     ----------
         broker (str): the broker to cancel the order on
         order_id (str/int): the id of the order to cancel
+        strategy (str, optional) : Name of the trading strategy to use, default is "Python".
         api_key (str, optional): The API key to use. Defaults to "default".
         api_secret (str, optional): The API secret to use. Defaults to "default".
 
@@ -1119,6 +1177,7 @@ class api:
             "data":
                 {
                     "broker": broker,
+                    "strategy":strategy,
                     "order_id":str(order_id)
                 }
 
@@ -1127,13 +1186,14 @@ class api:
         r = requests.post(url, data=json.dumps(data), headers=self.headers)
         return (r.json())
     
-    def ExitCOOrder(self, broker: str,order_id: str, api_key: str="default", api_secret: str="default"):
+    def ExitCOOrder(self, broker: str,order_id: str, strategy: str = "Python", api_key: str="default", api_secret: str="default"):
         """This function exits the specified open cover order on the specified broker based on the order id.
 
     Parameters
     ----------
         broker (str): the broker to cancel the order on
         order_id (str/int): the id of the order to cancel
+        strategy (str, optional) : Name of the trading strategy to use, default is "Python".
         api_key (str, optional): The API key to use. Defaults to "default".
         api_secret (str, optional): The API secret to use. Defaults to "default".
 
@@ -1149,6 +1209,7 @@ class api:
             "data":
                 {
                     "broker": broker,
+                    "strategy":strategy,
                     "order_id":str(order_id)
                 }
 
